@@ -10,7 +10,7 @@ use Exporter qw( import );
 
 our @EXPORT = qw( xy2d d2xy );
 
-our $VERSION = 1.002;
+our $VERSION = 1.003;
 
 # optional constructor if you want OO-style
 sub new {
@@ -156,6 +156,11 @@ was provided via new().
 
 =back
 
+=head1 CAVEATS
+
+If your platform has I<$n> bit integers, things will go badly if you try a side
+length longer than I<$n / 2>.
+
 =head1 BUGS
 
 Please let me know via the CPAN RT if you find any algorithmic defects. I'm
